# Primitive Arrays

Arrays of non-geospatial types. These exist to be used as _return_ types from
geospatial operations to maintain strong typing.

- [`BooleanArray`](#geoarrow.rust.core.BooleanArray)
<!-- - [`Float16Array`](#geoarrow.rust.core.Float16Array)
- [`Float32Array`](#geoarrow.rust.core.Float32Array) -->
- [`Float64Array`](#geoarrow.rust.core.Float64Array)
<!-- - [`UInt8Array`](#geoarrow.rust.core.UInt8Array)
- [`UInt16Array`](#geoarrow.rust.core.UInt16Array)
- [`UInt32Array`](#geoarrow.rust.core.UInt32Array)
- [`UInt64Array`](#geoarrow.rust.core.UInt64Array)
- [`Int8Array`](#geoarrow.rust.core.Int8Array)
- [`Int16Array`](#geoarrow.rust.core.Int16Array)
- [`Int32Array`](#geoarrow.rust.core.Int32Array)
- [`Int64Array`](#geoarrow.rust.core.Int64Array)
- [`StringArray`](#geoarrow.rust.core.StringArray)
- [`LargeStringArray`](#geoarrow.rust.core.LargeStringArray) -->

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
        - "^__arrow"
      members:
        - BooleanArray
        - Float64Array
